import os
import sys


# Temporary directory for packaging scripts to speed up consecutive builds. Created on application start.
temporary_directory = None

# Frontend
FRONTEND_ASSET_FOLDER = os.path.join(os.path.dirname(os.path.realpath(__file__)), 'web')

# Pre-defined variables by Python
DEFAULT_RECURSION_LIMIT = sys.getrecursionlimit()

# Argument-influenced configuration
package_filename = None
disable_chrome = False
supplied_ui_configuration = None

# Build
DEFAULT_OUTPUT_FOLDER = os.path.abspath('output')



import os
import platform

from eel import chrome


def can_use_chrome():
    """ Identify if Chrome is available for Eel to use """
    chrome_instance_path = chrome.find_path()
    return chrome_instance_path is not None and os.path.exists(chrome_instance_path)


def open_output_folder(folder):
    """ Open a folder in the local file explorer """
    folder_directory = os.path.abspath(folder)
    if platform.system() == 'Windows':
        os.startfile(folder_directory, 'explore')
    elif platform.system() == 'Linux':
        os.system('xdg-open "' + folder_directory + '"')
    elif platform.system() == 'Darwin':
        os.system('open "' + folder_directory + '"')
    else:
        return False
    return True



import argparse
import logging
import shutil
import tempfile

from . import __version__
from . import config
from . import validation
from . import ui


def run():
    """ Open the interface """
    # Setup a temporary folder to build in
    config.temporary_directory = tempfile.mkdtemp()

    # Suppress the global logger to only show error+ to the console
    logging.getLogger().handlers[0].setLevel(logging.ERROR)

    # Start UI
    ui.start(not config.disable_chrome)

    # Remove temporary folder to clean up from builds
    shutil.rmtree(config.temporary_directory)


if __name__ == '__main__':
    # Parse arguments
    parser = argparse.ArgumentParser()
    parser.add_argument(
        "filename",
        nargs='?',
        type=validation.argparse_file_eists,
        help="pass a file into the interface",
        default=None
    )
    parser.add_argument(
        "-nc",
        "--no-chrome",
        action="store_true",
        help="do not open in chromes app mode",
    )
    parser.add_argument(
        "-c",
        "--config",
        nargs='?',
        type=validation.argparse_file_json,
        help="a json file containing a UI configuration",
        default=None
    )
    parser.add_argument(
        "--version",
        action="store_true",
        help="print the version - will not run the ui"
    )
    args = parser.parse_args()

    # Setup config from arguments
    config.package_filename = args.filename
    config.disable_chrome = args.no_chrome
    config.supplied_ui_configuration = args.config

    # If the user has asked for the version, print it, otherwise run the application
    if args.version:
        print('auto-py-to-exe ' + __version__)
    else:
        run()
